@@ -34,10 +34,8 @@
 #include <gio/gio.h>
 #include <lcms2.h>
 
-#include "egg-debug.h"
-
 #include "gcm-profile.h"
-#include "gcm-xyz.h"
+#include "gcm-color.h"
 
 static void     gcm_profile_finalize	(GObject     *object);
 
@@ -63,19 +61,17 @@ struct _GcmProfilePrivate
 	gchar			*model;
 	gchar			*datetime;
 	gchar			*checksum;
-	GcmXyz			*white;
-	GcmXyz			*black;
-	GcmXyz			*red;
-	GcmXyz			*green;
-	GcmXyz			*blue;
+	guint			 temperature;
+	GHashTable		*dict;
+	GcmColorXYZ		*white;
+	GcmColorXYZ		*black;
+	GcmColorXYZ		*red;
+	GcmColorXYZ		*green;
+	GcmColorXYZ		*blue;
 	GFile			*file;
 	GFileMonitor		*monitor;
 	gboolean		 has_mlut;
 	cmsHPROFILE		 lcms_profile;
-	GcmClutData		*vcgt_data;
-	guint			 vcgt_data_size;
-	GcmClutData		*mlut_data;
-	guint			 mlut_data_size;
 };
 
 enum {
@@ -97,6 +93,7 @@ enum {
 	PROP_RED,
 	PROP_GREEN,
 	PROP_BLUE,
+	PROP_TEMPERATURE,
 	PROP_LAST
 };
 
@@ -112,7 +109,7 @@ static void gcm_profile_file_monitor_changed_cb (GFileMonitor *monitor, GFile *f
  *
  * Return value: The profile description as a string.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 const gchar *
 gcm_profile_get_description (GcmProfile *profile)
@@ -121,7 +118,6 @@ gcm_profile_get_description (GcmProfile *profile)
 	return profile->priv->description;
 }
 
-
 /**
  * gcm_profile_ensure_printable:
  **/
@@ -152,7 +148,7 @@ gcm_profile_ensure_printable (gchar *text)
  *
  * Sets the description of the profile.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_description (GcmProfile *profile, const gchar *description)
@@ -188,7 +184,7 @@ gcm_profile_set_description (GcmProfile *profile, const gchar *description)
  * Return value: %TRUE if the description mentions the profile colorspace explicity,
  * e.g. "Adobe RGB" for %GCM_COLORSPACE_RGB.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_profile_has_colorspace_description (GcmProfile *profile)
@@ -206,6 +202,91 @@ gcm_profile_has_colorspace_description (GcmProfile *profile)
 	return FALSE;
 }
 
+/**
+ * gcm_profile_get_temperature:
+ * @profile: A valid #GcmProfile
+ *
+ * Gets the profile color temperature, rounded to the nearest 100K.
+ *
+ * Return value: The color temperature in Kelvins, or 0 for error.
+ *
+ * Since: 2.91.1
+ **/
+guint
+gcm_profile_get_temperature (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), 0);
+	return profile->priv->temperature;
+}
+
+/**
+ * gcm_profile_get_red:
+ * @profile: a valid #GcmProfile instance
+ *
+ * Gets the monitor red chromaticity value.
+ *
+ * Return value: the #GcmColorXYZ value
+ *
+ * Since: 2.91.1
+ **/
+const GcmColorXYZ *
+gcm_profile_get_red (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->red;
+}
+
+/**
+ * gcm_profile_get_green:
+ * @profile: a valid #GcmProfile instance
+ *
+ * Gets the monitor green chromaticity value.
+ *
+ * Return value: the #GcmColorXYZ value
+ *
+ * Since: 2.91.1
+ **/
+const GcmColorXYZ *
+gcm_profile_get_green (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->green;
+}
+
+/**
+ * gcm_profile_get_blue:
+ * @profile: a valid #GcmProfile instance
+ *
+ * Gets the monitor red chromaticity value.
+ *
+ * Return value: the #GcmColorXYZ value
+ *
+ * Since: 2.91.1
+ **/
+const GcmColorXYZ *
+gcm_profile_get_blue (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->blue;
+}
+
+/**
+ * gcm_profile_get_white:
+ * @profile: a valid #GcmProfile instance
+ *
+ * Gets the monitor white chromaticity value.
+ *
+ * Return value: the #GcmColorXYZ value
+ *
+ * Since: 2.91.1
+ **/
+const GcmColorXYZ *
+gcm_profile_get_white (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->white;
+}
+
 /**
  * gcm_profile_get_file:
  * @profile: A valid #GcmProfile
@@ -214,7 +295,7 @@ gcm_profile_has_colorspace_description (GcmProfile *profile)
  *
  * Return value: A #GFile, or %NULL. Do not free.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 GFile *
 gcm_profile_get_file (GcmProfile *profile)
@@ -230,7 +311,7 @@ gcm_profile_get_file (GcmProfile *profile)
  *
  * Sets the file to be used when reading the profile.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_file (GcmProfile *profile, GFile *file)
@@ -266,7 +347,7 @@ gcm_profile_set_file (GcmProfile *profile, GFile *file)
  *
  * Return value: A filename, or %NULL
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 const gchar *
 gcm_profile_get_filename (GcmProfile *profile)
@@ -276,7 +357,7 @@ gcm_profile_get_filename (GcmProfile *profile)
 	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
 
 	/* this returns a const, so we have to track it internally */
-	if (priv->filename == NULL)
+	if (priv->filename == NULL && priv->file != NULL)
 		priv->filename = g_file_get_path (priv->file);
 	return priv->filename;
 }
@@ -289,7 +370,7 @@ gcm_profile_get_filename (GcmProfile *profile)
  *
  * Return value: A string. Do not free.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 const gchar *
 gcm_profile_get_copyright (GcmProfile *profile)
@@ -305,7 +386,7 @@ gcm_profile_get_copyright (GcmProfile *profile)
  *
  * Sets the copyright string.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_copyright (GcmProfile *profile, const gchar *copyright)
@@ -329,7 +410,7 @@ gcm_profile_set_copyright (GcmProfile *profile, const gchar *copyright)
  *
  * Return value: A string. Do not free.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 const gchar *
 gcm_profile_get_model (GcmProfile *profile)
@@ -345,7 +426,7 @@ gcm_profile_get_model (GcmProfile *profile)
  *
  * Sets the device model name.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_model (GcmProfile *profile, const gchar *model)
@@ -369,7 +450,7 @@ gcm_profile_set_model (GcmProfile *profile, const gchar *model)
  *
  * Return value: A string. Do not free.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 const gchar *
 gcm_profile_get_manufacturer (GcmProfile *profile)
@@ -385,7 +466,7 @@ gcm_profile_get_manufacturer (GcmProfile *profile)
  *
  * Sets the device manufacturer name.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_manufacturer (GcmProfile *profile, const gchar *manufacturer)
@@ -409,7 +490,7 @@ gcm_profile_set_manufacturer (GcmProfile *profile, const gchar *manufacturer)
  *
  * Return value: A string. Do not free.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 const gchar *
 gcm_profile_get_datetime (GcmProfile *profile)
@@ -425,7 +506,7 @@ gcm_profile_get_datetime (GcmProfile *profile)
  *
  * Sets the profile date and time.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_datetime (GcmProfile *profile, const gchar *datetime)
@@ -441,6 +522,8 @@ gcm_profile_set_datetime (GcmProfile *profile, const gchar *datetime)
 
 /**
  * gcm_profile_get_checksum:
+ *
+ * Since: 2.91.1
  **/
 const gchar *
 gcm_profile_get_checksum (GcmProfile *profile)
@@ -466,6 +549,8 @@ gcm_profile_set_checksum (GcmProfile *profile, const gchar *checksum)
 
 /**
  * gcm_profile_get_size:
+ *
+ * Since: 2.91.1
  **/
 guint
 gcm_profile_get_size (GcmProfile *profile)
@@ -477,7 +562,7 @@ gcm_profile_get_size (GcmProfile *profile)
 /**
  * gcm_profile_set_size:
  **/
-void
+static void
 gcm_profile_set_size (GcmProfile *profile, guint size)
 {
 	g_return_if_fail (GCM_IS_PROFILE (profile));
@@ -487,6 +572,8 @@ gcm_profile_set_size (GcmProfile *profile, guint size)
 
 /**
  * gcm_profile_get_kind:
+ *
+ * Since: 2.91.1
  **/
 GcmProfileKind
 gcm_profile_get_kind (GcmProfile *profile)
@@ -497,6 +584,8 @@ gcm_profile_get_kind (GcmProfile *profile)
 
 /**
  * gcm_profile_set_kind:
+ *
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_kind (GcmProfile *profile, GcmProfileKind kind)
@@ -508,6 +597,8 @@ gcm_profile_set_kind (GcmProfile *profile, GcmProfileKind kind)
 
 /**
  * gcm_profile_get_colorspace:
+ *
+ * Since: 2.91.1
  **/
 GcmColorspace
 gcm_profile_get_colorspace (GcmProfile *profile)
@@ -518,6 +609,8 @@ gcm_profile_get_colorspace (GcmProfile *profile)
 
 /**
  * gcm_profile_set_colorspace:
+ *
+ * Since: 2.91.1
  **/
 void
 gcm_profile_set_colorspace (GcmProfile *profile, GcmColorspace colorspace)
@@ -529,6 +622,8 @@ gcm_profile_set_colorspace (GcmProfile *profile, GcmColorspace colorspace)
 
 /**
  * gcm_profile_get_has_vcgt:
+ *
+ * Since: 2.91.1
  **/
 gboolean
 gcm_profile_get_has_vcgt (GcmProfile *profile)
@@ -540,7 +635,7 @@ gcm_profile_get_has_vcgt (GcmProfile *profile)
 /**
  * gcm_profile_set_has_vcgt:
  **/
-void
+static void
 gcm_profile_set_has_vcgt (GcmProfile *profile, gboolean has_vcgt)
 {
 	g_return_if_fail (GCM_IS_PROFILE (profile));
@@ -552,6 +647,8 @@ gcm_profile_set_has_vcgt (GcmProfile *profile, gboolean has_vcgt)
  * gcm_profile_get_handle:
  *
  * Return value: Do not call cmsCloseProfile() on this value!
+ *
+ * Since: 2.91.1
  **/
 gpointer
 gcm_profile_get_handle (GcmProfile *profile)
@@ -562,6 +659,8 @@ gcm_profile_get_handle (GcmProfile *profile)
 
 /**
  * gcm_profile_get_can_delete:
+ *
+ * Since: 2.91.1
  **/
 gboolean
 gcm_profile_get_can_delete (GcmProfile *profile)
@@ -595,7 +694,7 @@ gcm_utils_format_date_time (const struct tm *created)
  *
  * Return value: %TRUE for success
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, GError **error)
@@ -612,7 +711,7 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 	cmsHTRANSFORM transform;
 	gchar *text = NULL;
 	gchar *checksum = NULL;
-	GcmXyz *xyz;
+	gboolean got_illuminants = FALSE;
 	GcmProfilePrivate *priv = profile->priv;
 
 	g_return_val_if_fail (GCM_IS_PROFILE (profile), FALSE);
@@ -639,27 +738,39 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 	/* get white point */
 	cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigMediaWhitePointTag);
 	if (cie_xyz != NULL) {
-		g_object_set (priv->white,
-			      "cie-x", cie_xyz->X,
-			      "cie-y", cie_xyz->Y,
-			      "cie-z", cie_xyz->Z,
-			      NULL);
+		cmsCIExyY xyY;
+		gdouble temp_float;
+		gcm_color_set_XYZ (priv->white,
+				   cie_xyz->X, cie_xyz->Y, cie_xyz->Z);
+
+		/* convert to lcms xyY values */
+		cmsXYZ2xyY (&xyY, cie_xyz);
+		g_debug ("whitepoint = %f,%f [%f]", xyY.x, xyY.y, xyY.Y);
+
+		/* get temperature */
+		ret = cmsTempFromWhitePoint (&temp_float, &xyY);
+		if (ret) {
+			/* round to nearest 100K */
+			priv->temperature = (((guint) temp_float) / 100) * 100;
+			g_debug ("color temperature = %i", priv->temperature);
+		} else {
+			priv->temperature = 0;
+			g_warning ("failed to get color temperature");
+		}
 	} else {
-		gcm_xyz_clear (priv->white);
-		egg_warning ("failed to get white point");
+		/* this is no big suprise, some profiles don't have these */
+		gcm_color_clear_XYZ (priv->white);
+		g_debug ("failed to get white point");
 	}
 
 	/* get black point */
 	cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigMediaBlackPointTag);
 	if (cie_xyz != NULL) {
-		g_object_set (priv->black,
-			      "cie-x", cie_xyz->X,
-			      "cie-y", cie_xyz->Y,
-			      "cie-z", cie_xyz->Z,
-			      NULL);
+		gcm_color_set_XYZ (priv->black,
+				   cie_xyz->X, cie_xyz->Y, cie_xyz->Z);
 	} else {
-		gcm_xyz_clear (priv->black);
-		egg_warning ("failed to get black point");
+		/* this is no big suprise, most profiles don't have these */
+		gcm_color_clear_XYZ (priv->black);
 	}
 
 	/* get the profile kind */
@@ -729,8 +840,24 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 	}
 	gcm_profile_set_colorspace (profile, colorspace);
 
-	/* get the illuminants by running it through the profile */
+	/* get the illuminants from the primaries */
 	if (color_space == cmsSigRgbData) {
+		cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigRedMatrixColumnTag);
+		if (cie_xyz != NULL) {
+			/* assume that if red is present, the green and blue are too */
+			gcm_color_copy_XYZ ((GcmColorXYZ *) cie_xyz, (GcmColorXYZ *) &cie_illum.Red);
+			cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigGreenMatrixColumnTag);
+			gcm_color_copy_XYZ ((GcmColorXYZ *) cie_xyz, (GcmColorXYZ *) &cie_illum.Green);
+			cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigBlueMatrixColumnTag);
+			gcm_color_copy_XYZ ((GcmColorXYZ *) cie_xyz, (GcmColorXYZ *) &cie_illum.Blue);
+			got_illuminants = TRUE;
+		} else {
+			g_debug ("failed to get illuminants");
+		}
+	}
+
+	/* get the illuminants by running it through the profile */
+	if (!got_illuminants && color_space == cmsSigRgbData) {
 		gdouble rgb_values[3];
 
 		/* create a transform from profile to XYZ */
@@ -758,7 +885,9 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 
 			/* we're done */
 			cmsDeleteTransform (transform);
-			ret = TRUE;
+			got_illuminants = TRUE;
+		} else {
+			g_debug ("failed to run through profile");
 		}
 
 		/* no more need for the output profile */
@@ -766,44 +895,18 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 	}
 
 	/* we've got valid values */
-	if (ret) {
-		/* red */
-		xyz = gcm_xyz_new ();
-		g_object_set (xyz,
-			      "cie-x", cie_illum.Red.X,
-			      "cie-y", cie_illum.Red.Y,
-			      "cie-z", cie_illum.Red.Z,
-			      NULL);
-		g_object_set (profile,
-			      "red", xyz,
-			      NULL);
-		g_object_unref (xyz);
-
-		/* green */
-		xyz = gcm_xyz_new ();
-		g_object_set (xyz,
-			      "cie-x", cie_illum.Green.X,
-			      "cie-y", cie_illum.Green.Y,
-			      "cie-z", cie_illum.Green.Z,
-			      NULL);
-		g_object_set (profile,
-			      "green", xyz,
-			      NULL);
-		g_object_unref (xyz);
-
-		/* blue */
-		xyz = gcm_xyz_new ();
-		g_object_set (xyz,
-			      "cie-x", cie_illum.Blue.X,
-			      "cie-y", cie_illum.Blue.Y,
-			      "cie-z", cie_illum.Blue.Z,
-			      NULL);
-		g_object_set (profile,
-			      "blue", xyz,
-			      NULL);
-		g_object_unref (xyz);
+	if (got_illuminants) {
+		gcm_color_set_XYZ (priv->red,
+				   cie_illum.Red.X, cie_illum.Red.Y, cie_illum.Red.Z);
+		gcm_color_set_XYZ (priv->green,
+				   cie_illum.Green.X, cie_illum.Green.Y, cie_illum.Green.Z);
+		gcm_color_set_XYZ (priv->blue,
+				   cie_illum.Blue.X, cie_illum.Blue.Y, cie_illum.Blue.Z);
 	} else {
-		egg_debug ("failed to get luminance values");
+		g_debug ("failed to get luminance values");
+		gcm_color_clear_XYZ (priv->red);
+		gcm_color_clear_XYZ (priv->green);
+		gcm_color_clear_XYZ (priv->blue);
 	}
 
 	/* get the profile created time and date */
@@ -859,11 +962,11 @@ out:
  * @file: A GFile pointing to a profile
  * @error: A #GError, or %NULL
  *
- * Parses a profile filename, filling in all the details possible.
+ * Parses a profile file, filling in all the details possible.
  *
  * Return value: %TRUE for success
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_profile_parse (GcmProfile *profile, GFile *file, GError **error)
@@ -906,6 +1009,108 @@ out:
 	return ret;
 }
 
+/*
+ * _cmsWriteTagTextAscii:
+ */
+static cmsBool
+_cmsWriteTagTextAscii (cmsHPROFILE lcms_profile, cmsTagSignature sig, const gchar *text)
+{
+	cmsBool ret;
+	cmsMLU *mlu = cmsMLUalloc (0, 1);
+	cmsMLUsetASCII (mlu, "EN", "us", text);
+	ret = cmsWriteTag (lcms_profile, sig, mlu);
+	cmsMLUfree (mlu);
+	return ret;
+}
+
+/**
+ * gcm_profile_set_whitepoint:
+ * @profile: A valid #GcmProfile
+ * @whitepoint: the whitepoint
+ * @error: A #GError, or %NULL
+ *
+ * Saves the whitepoint data to a file.
+ *
+ * Return value: %TRUE for success
+ *
+ * Since: 2.91.1
+ **/
+gboolean
+gcm_profile_set_whitepoint (GcmProfile *profile, const GcmColorXYZ *whitepoint, GError **error)
+{
+	gboolean ret;
+	GcmProfilePrivate *priv = profile->priv;
+
+	/* not loaded */
+	if (priv->lcms_profile == NULL)
+		priv->lcms_profile = cmsCreateProfilePlaceholder (NULL);
+
+	/* copy */
+	gcm_color_copy_XYZ (whitepoint, priv->white);
+
+	/* write tag */
+	ret = cmsWriteTag (priv->lcms_profile, cmsSigMediaWhitePointTag, priv->white);
+	if (!ret) {
+		g_set_error_literal (error, 1, 0, "failed to set write cmsSigMediaWhitePointTag");
+		goto out;
+	}
+out:
+	return ret;
+}
+
+/**
+ * gcm_profile_set_primaries:
+ * @profile: A valid #GcmProfile
+ * @red: the red primary
+ * @green: the green primary
+ * @blue: the blue primary
+ * @error: A #GError, or %NULL
+ *
+ * Saves the primaries data to a file.
+ *
+ * Return value: %TRUE for success
+ *
+ * Since: 2.91.1
+ **/
+gboolean
+gcm_profile_set_primaries (GcmProfile *profile,
+			   const GcmColorXYZ *red,
+			   const GcmColorXYZ *green,
+			   const GcmColorXYZ *blue,
+			   GError **error)
+{
+	gboolean ret;
+	GcmProfilePrivate *priv = profile->priv;
+
+	/* not loaded */
+	if (priv->lcms_profile == NULL)
+		priv->lcms_profile = cmsCreateProfilePlaceholder (NULL);
+
+	/* copy */
+	gcm_color_copy_XYZ (red, priv->red);
+	gcm_color_copy_XYZ (green, priv->green);
+	gcm_color_copy_XYZ (blue, priv->blue);
+
+	/* write tags */
+	ret = cmsWriteTag (priv->lcms_profile, cmsSigRedMatrixColumnTag, priv->red);
+	if (!ret) {
+		g_set_error_literal (error, 1, 0, "failed to set write cmsSigRedMatrixColumnTag");
+		goto out;
+	}
+	ret = cmsWriteTag (priv->lcms_profile, cmsSigGreenMatrixColumnTag, priv->green);
+	if (!ret) {
+		g_set_error_literal (error, 1, 0, "failed to set write cmsSigGreenMatrixColumnTag");
+		goto out;
+	}
+	ret = cmsWriteTag (priv->lcms_profile, cmsSigBlueMatrixColumnTag, priv->blue);
+	if (!ret) {
+		g_set_error_literal (error, 1, 0, "failed to set write cmsSigBlueMatrixColumnTag");
+		goto out;
+	}
+out:
+	return ret;
+}
+
 /**
  * gcm_profile_save:
  * @profile: A valid #GcmProfile
@@ -916,24 +1121,265 @@ out:
  *
  * Return value: %TRUE for success
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_profile_save (GcmProfile *profile, const gchar *filename, GError **error)
 {
+	GFile *file = NULL;
 	gboolean ret = FALSE;
 	GcmProfilePrivate *priv = profile->priv;
 
 	/* not loaded */
-	if (priv->size == 0) {
-		g_set_error_literal (error, 1, 0, "not loaded");
+	if (priv->lcms_profile == NULL) {
+		g_set_error_literal (error, 1, 0, "not loaded or generated");
 		goto out;
 	}
 
+	/* this is all we support writing */
+	if (priv->colorspace == GCM_COLORSPACE_RGB) {
+		cmsSetColorSpace (priv->lcms_profile, cmsSigRgbData);
+		cmsSetPCS (priv->lcms_profile, cmsSigLabData);
+	}
+	if (priv->kind == GCM_PROFILE_KIND_DISPLAY_DEVICE)
+		cmsSetDeviceClass (priv->lcms_profile, cmsSigDisplayClass);
+
+	/* write text data */
+	if (priv->description != NULL) {
+		ret = _cmsWriteTagTextAscii (priv->lcms_profile,
+					     cmsSigProfileDescriptionTag,
+					     priv->description);
+		if (!ret) {
+			g_set_error_literal (error, 1, 0, "failed to write description");
+			goto out;
+		}
+	}
+	if (priv->copyright != NULL) {
+		ret = _cmsWriteTagTextAscii (priv->lcms_profile,
+					     cmsSigCopyrightTag,
+					     priv->copyright);
+		if (!ret) {
+			g_set_error_literal (error, 1, 0, "failed to write copyright");
+			goto out;
+		}
+	}
+	if (priv->model != NULL) {
+		ret = _cmsWriteTagTextAscii (priv->lcms_profile,
+					     cmsSigDeviceModelDescTag,
+					     priv->model);
+		if (!ret) {
+			g_set_error_literal (error, 1, 0, "failed to write model");
+			goto out;
+		}
+	}
+	if (priv->manufacturer != NULL) {
+		ret = _cmsWriteTagTextAscii (priv->lcms_profile,
+					     cmsSigDeviceMfgDescTag,
+					     priv->manufacturer);
+		if (!ret) {
+			g_set_error_literal (error, 1, 0, "failed to write manufacturer");
+			goto out;
+		}
+	}
+
 	/* save, TODO: get error */
 	cmsSaveProfileToFile (priv->lcms_profile, filename);
 	ret = TRUE;
+
+	/* the profile now tracks the saved file */
+	if (priv->filename == NULL) {
+		g_debug ("assuming %s, so re-parse", filename);
+		file = g_file_new_for_path (filename);
+		ret = gcm_profile_parse (profile, file, error);
+		if (!ret)
+			goto out;
+	}
+
 out:
+	if (file != NULL)
+		g_object_unref (file);
+	return ret;
+}
+
+/**
+ * gcm_profile_get_data:
+ * @profile: A valid #GcmProfile
+ * @key: the dictionary key
+ *
+ * Gets an item of data from the profile dictionary.
+ *
+ * Return value: The dictinary data, or %NULL if the key does not exist.
+ *
+ * Since: 2.91.2
+ **/
+const gchar *
+gcm_profile_get_data (GcmProfile *profile, const gchar *key)
+{
+	g_warning ("lcms2 support for dict missing: Cannot get %s", key);
+	return (const gchar *) g_hash_table_lookup (profile->priv->dict, key);
+}
+
+/**
+ * gcm_profile_get_data:
+ * @profile: A valid #GcmProfile
+ * @key: the dictionary key
+ * @data: the dictionary data
+ *
+ * Sets an item of data from the profile dictionary, overwriting it if
+ * it already exists.
+ *
+ * Since: 2.91.2
+ **/
+void
+gcm_profile_set_data (GcmProfile *profile, const gchar *key, const gchar *data)
+{
+	g_warning ("lcms2 support for dict missing: Cannot set %s to %s", key, data);
+	g_hash_table_insert (profile->priv->dict, g_strdup (key), g_strdup (data));
+}
+
+/**
+ * gcm_profile_create_from_chroma:
+ * @profile: A valid #GcmProfile
+ * @red: primary color data
+ * @green: primary color data
+ * @blue: primary color data
+ * @white: whitepoint data
+ * @error: A #GError, or %NULL
+ *
+ * Saves the profile data to a file.
+ *
+ * Return value: %TRUE for success
+ *
+ * Since: 2.91.1
+ **/
+gboolean
+gcm_profile_create_from_chroma (GcmProfile *profile, gdouble gamma,
+				const GcmColorYxy *red,
+				const GcmColorYxy *green,
+				const GcmColorYxy *blue,
+				const GcmColorYxy *white,
+				GError **error)
+{
+	gboolean ret = FALSE;
+	cmsCIExyYTRIPLE chroma;
+	cmsToneCurve *transfer_curve[3];
+	cmsCIExyY white_point;
+	GcmProfilePrivate *priv = profile->priv;
+
+	/* not loaded */
+	if (priv->lcms_profile != NULL) {
+		g_set_error_literal (error, 1, 0, "already loaded or generated");
+		goto out;
+	}
+
+	/* copy data from our structures (which are the wrong packing
+	 * size for lcms2) */
+	chroma.Red.x = red->x;
+	chroma.Red.y = red->y;
+	chroma.Green.x = green->x;
+	chroma.Green.y = green->y;
+	chroma.Blue.x = blue->x;
+	chroma.Blue.y = blue->y;
+	white_point.x = white->x;
+	white_point.y = white->y;
+	white_point.Y = 1.0;
+
+	/* estimate the transfer function for the gamma */
+	transfer_curve[0] = transfer_curve[1] = transfer_curve[2] = cmsBuildGamma (NULL, gamma);
+
+	/* create our generated profile */
+	priv->lcms_profile = cmsCreateRGBProfile (&white_point, &chroma, transfer_curve);
+	cmsSetEncodedICCversion (priv->lcms_profile, 2);
+	cmsFreeToneCurve (*transfer_curve);
+
+	/* success */
+	ret = TRUE;
+out:
+	return ret;
+}
+
+/**
+ * gcm_profile_guess_and_add_vcgt:
+ * @profile: A valid #GcmProfile
+ * @error: A #GError, or %NULL
+ *
+ * Runs a grey image through the profile, to guess semi-correct VCGT curves
+ *
+ * Return value: %TRUE for success
+ *
+ * Since: 2.91.1
+ **/
+gboolean
+gcm_profile_guess_and_add_vcgt (GcmProfile *profile, GError **error)
+{
+	cmsHPROFILE srgb_profile = NULL;
+	cmsHTRANSFORM transform = NULL;
+	cmsToneCurve *transfer_curve[3];
+	cmsUInt16Number rawdata[3][256];
+	const guint size = 256;
+	gboolean ret = FALSE;
+	gdouble *values_in = NULL;
+	gdouble *values_out = NULL;
+	gfloat divadd;
+	gfloat divamount;
+	guint i;
+	GcmProfilePrivate *priv = profile->priv;
+
+	/* not loaded */
+	if (priv->lcms_profile == NULL) {
+		g_set_error_literal (error, 1, 0, "not already loaded or generated");
+		goto out;
+	}
+
+	/* create arrays */
+	values_in = g_new0 (gdouble, size * 3);
+	values_out = g_new0 (gdouble, size * 3);
+
+	/* populate with data */
+	divamount = 1.0f / (gfloat) (size - 1);
+	for (i=0; i<size; i++) {
+		divadd = divamount * (gfloat) i;
+
+		/* grey component */
+		values_in[(i * 3)+0] = divadd;
+		values_in[(i * 3)+1] = divadd;
+		values_in[(i * 3)+2] = divadd;
+	}
+
+	/* create a transform from sRGB to profile */
+	srgb_profile = cmsCreate_sRGBProfile ();
+	transform = cmsCreateTransform (priv->lcms_profile, TYPE_RGB_DBL,
+					srgb_profile, TYPE_RGB_DBL,
+					INTENT_ABSOLUTE_COLORIMETRIC, 0);
+	if (transform == NULL) {
+		g_set_error_literal (error, 1, 0, "failed to generate transform");
+		goto out;
+	}
+
+	/* do transform */
+	cmsDoTransform (transform, values_in, values_out, size);
+
+	/* unroll the data */
+	for (i=0; i<size; i++) {
+		rawdata[0][i] = values_out[(i * 3)+0] * 0xffff;
+		rawdata[1][i] = values_out[(i * 3)+1] * 0xffff;
+		rawdata[2][i] = values_out[(i * 3)+2] * 0xffff;
+	}
+
+	/* build tone curves */
+	for (i=0; i<3; i++)
+		transfer_curve[i] = cmsBuildTabulatedToneCurve16 (NULL, 256, rawdata[i]);
+
+	/* write to VCGT */
+	ret = cmsWriteTag (priv->lcms_profile, cmsSigVcgtType, transfer_curve);
+	cmsFreeToneCurveTriple (transfer_curve);
+out:
+	g_free (values_in);
+	g_free (values_out);
+	if (transform != NULL)
+		cmsDeleteTransform (transform);
+	if (srgb_profile != NULL)
+		cmsCloseProfile (srgb_profile);
 	return ret;
 }
 
@@ -946,7 +1392,7 @@ out:
  *
  * Return value: A #GcmClut object, or %NULL. Free with g_object_unref()
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 GcmClut *
 gcm_profile_generate_vcgt (GcmProfile *profile, guint size)
@@ -962,7 +1408,7 @@ gcm_profile_generate_vcgt (GcmProfile *profile, guint size)
 	/* get tone curves from profile */
 	vcgt = cmsReadTag (priv->lcms_profile, cmsSigVcgtType);
 	if (vcgt == NULL || vcgt[0] == NULL) {
-		egg_debug ("profile does not have any VCGT data");
+		g_debug ("profile does not have any VCGT data");
 		goto out;
 	}
 
@@ -986,6 +1432,63 @@ out:
 	return clut;
 }
 
+/**
+ * gcm_profile_set_vcgt_from_data:
+ * @profile: A valid #GcmProfile
+ * @red: red color data
+ * @green: green color data
+ * @blue: blue color data
+ * @size: the size of the color curves.
+ *
+ * Sets a VCGT curve of a specified size.
+ *
+ * Return value: %TRUE for success
+ *
+ * Since: 2.91.1
+ **/
+gboolean
+gcm_profile_set_vcgt_from_data (GcmProfile *profile, guint16 *red, guint16 *green, guint16 *blue, guint size, GError **error)
+{
+	guint i;
+	gboolean ret = FALSE;
+	cmsToneCurve *vcgt_curve[3];
+	GcmProfilePrivate *priv = profile->priv;
+
+	/* not loaded or created */
+	if (priv->lcms_profile == NULL)
+		priv->lcms_profile = cmsCreateProfilePlaceholder (NULL);
+
+	/* check monotonic */
+	for (i=0; i<size-1; i++) {
+		if (red[i] > red[i+1] ||
+		    green[i] > green[i+1] ||
+		    blue[i] > blue[i+1]) {
+			g_set_error_literal (error, 1, 0, "CVGT data not monotonic");
+			goto out;
+		}
+	}
+
+	/* build tone curve */
+	vcgt_curve[0] = cmsBuildTabulatedToneCurve16 (NULL, size, red);
+	vcgt_curve[1] = cmsBuildTabulatedToneCurve16 (NULL, size, green);
+	vcgt_curve[2] = cmsBuildTabulatedToneCurve16 (NULL, size, blue);
+
+	/* smooth it */
+	for (i=0; i<3; i++)
+		cmsSmoothToneCurve (vcgt_curve[i], 5);
+
+	/* write the tag */
+	ret = cmsWriteTag (priv->lcms_profile, cmsSigVcgtType, vcgt_curve);
+	for (i=0; i<3; i++)
+		cmsFreeToneCurve (vcgt_curve[i]);
+	if (!ret) {
+		g_set_error_literal (error, 1, 0, "Failed to set vcgt");
+		goto out;
+	}
+out:
+	return ret;
+}
+
 /**
  * gcm_profile_generate_curve:
  * @profile: A valid #GcmProfile
@@ -995,7 +1498,7 @@ out:
  *
  * Return value: A #GcmClut object, or %NULL. Free with g_object_unref()
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 GcmClut *
 gcm_profile_generate_curve (GcmProfile *profile, guint size)
@@ -1100,22 +1603,24 @@ gcm_profile_file_monitor_changed_cb (GFileMonitor *monitor, GFile *file, GFile *
 		goto out;
 
 	/* just rescan everything */
-	egg_debug ("%s deleted, clearing filename", priv->filename);
+	g_debug ("%s deleted, clearing filename", priv->filename);
 	if (priv->file != NULL)
 		g_object_unref (priv->file);
 	priv->file = NULL;
+	g_free (priv->filename);
+	priv->filename = NULL;
+	g_object_notify (G_OBJECT (profile), "file");
 out:
 	return;
 }
 
-
 /**
  * gcm_profile_error_cb:
  **/
 static void
 gcm_profile_error_cb (cmsContext ContextID, cmsUInt32Number errorcode, const char *text)
 {
-	egg_warning ("LCMS error %i: %s", errorcode, text);
+	g_warning ("LCMS error %i: %s", errorcode, text);
 }
 
 /**
@@ -1165,19 +1670,22 @@ gcm_profile_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 		g_value_set_boolean (value, priv->can_delete);
 		break;
 	case PROP_WHITE:
-		g_value_set_object (value, priv->white);
+		g_value_set_boxed (value, g_boxed_copy (GCM_TYPE_COLOR_XYZ, priv->white));
 		break;
 	case PROP_BLACK:
-		g_value_set_object (value, priv->black);
+		g_value_set_boxed (value, g_boxed_copy (GCM_TYPE_COLOR_XYZ, priv->black));
 		break;
 	case PROP_RED:
-		g_value_set_object (value, priv->red);
+		g_value_set_boxed (value, g_boxed_copy (GCM_TYPE_COLOR_XYZ, priv->red));
 		break;
 	case PROP_GREEN:
-		g_value_set_object (value, priv->green);
+		g_value_set_boxed (value, g_boxed_copy (GCM_TYPE_COLOR_XYZ, priv->green));
 		break;
 	case PROP_BLUE:
-		g_value_set_object (value, priv->blue);
+		g_value_set_boxed (value, g_boxed_copy (GCM_TYPE_COLOR_XYZ, priv->blue));
+		break;
+	case PROP_TEMPERATURE:
+		g_value_set_uint (value, priv->temperature);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1226,19 +1734,19 @@ gcm_profile_set_property (GObject *object, guint prop_id, const GValue *value, G
 		gcm_profile_set_has_vcgt (profile, g_value_get_boolean (value));
 		break;
 	case PROP_WHITE:
-		priv->white = g_value_dup_object (value);
+		gcm_color_copy_XYZ (g_value_get_boxed (value), priv->white);
 		break;
 	case PROP_BLACK:
-		priv->black = g_value_dup_object (value);
+		gcm_color_copy_XYZ (g_value_get_boxed (value), priv->black);
 		break;
 	case PROP_RED:
-		priv->red = g_value_dup_object (value);
+		gcm_color_copy_XYZ (g_value_get_boxed (value), priv->red);
 		break;
 	case PROP_GREEN:
-		priv->green = g_value_dup_object (value);
+		gcm_color_copy_XYZ (g_value_get_boxed (value), priv->green);
 		break;
 	case PROP_BLUE:
-		priv->blue = g_value_dup_object (value);
+		gcm_color_copy_XYZ (g_value_get_boxed (value), priv->blue);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1357,43 +1865,51 @@ gcm_profile_class_init (GcmProfileClass *klass)
 	/**
 	 * GcmProfile:white:
 	 */
-	pspec = g_param_spec_object ("white", NULL, NULL,
-				     GCM_TYPE_XYZ,
-				     G_PARAM_READWRITE);
+	pspec = g_param_spec_boxed ("white", NULL, NULL,
+				    GCM_TYPE_COLOR_XYZ,
+				    G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_WHITE, pspec);
 
 	/**
 	 * GcmProfile:black:
 	 */
-	pspec = g_param_spec_object ("black", NULL, NULL,
-				     GCM_TYPE_XYZ,
-				     G_PARAM_READWRITE);
+	pspec = g_param_spec_boxed ("black", NULL, NULL,
+				    GCM_TYPE_COLOR_XYZ,
+				    G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_BLACK, pspec);
 
 	/**
 	 * GcmProfile:red:
 	 */
-	pspec = g_param_spec_object ("red", NULL, NULL,
-				     GCM_TYPE_XYZ,
-				     G_PARAM_READWRITE);
+	pspec = g_param_spec_boxed ("red", NULL, NULL,
+				    GCM_TYPE_COLOR_XYZ,
+				    G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_RED, pspec);
 
 	/**
 	 * GcmProfile:green:
 	 */
-	pspec = g_param_spec_object ("green", NULL, NULL,
-				     GCM_TYPE_XYZ,
-				     G_PARAM_READWRITE);
+	pspec = g_param_spec_boxed ("green", NULL, NULL,
+				    GCM_TYPE_COLOR_XYZ,
+				    G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_GREEN, pspec);
 
 	/**
 	 * GcmProfile:blue:
 	 */
-	pspec = g_param_spec_object ("blue", NULL, NULL,
-				     GCM_TYPE_XYZ,
-				     G_PARAM_READWRITE);
+	pspec = g_param_spec_boxed ("blue", NULL, NULL,
+				    GCM_TYPE_COLOR_XYZ,
+				    G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_BLUE, pspec);
 
+	/**
+	 * GcmProfile:temperature:
+	 */
+	pspec = g_param_spec_uint ("temperature", NULL, NULL,
+				   0, G_MAXUINT, 0,
+				   G_PARAM_READABLE);
+	g_object_class_install_property (object_class, PROP_TEMPERATURE, pspec);
+
 	g_type_class_add_private (klass, sizeof (GcmProfilePrivate));
 }
 
@@ -1404,17 +1920,16 @@ static void
 gcm_profile_init (GcmProfile *profile)
 {
 	profile->priv = GCM_PROFILE_GET_PRIVATE (profile);
-	profile->priv->vcgt_data = NULL;
-	profile->priv->mlut_data = NULL;
 	profile->priv->can_delete = FALSE;
 	profile->priv->monitor = NULL;
+	profile->priv->dict = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	profile->priv->kind = GCM_PROFILE_KIND_UNKNOWN;
 	profile->priv->colorspace = GCM_COLORSPACE_UNKNOWN;
-	profile->priv->white = gcm_xyz_new ();
-	profile->priv->black = gcm_xyz_new ();
-	profile->priv->red = gcm_xyz_new ();
-	profile->priv->green = gcm_xyz_new ();
-	profile->priv->blue = gcm_xyz_new ();
+	profile->priv->white = gcm_color_new_XYZ ();
+	profile->priv->black = gcm_color_new_XYZ ();
+	profile->priv->red = gcm_color_new_XYZ ();
+	profile->priv->green = gcm_color_new_XYZ ();
+	profile->priv->blue = gcm_color_new_XYZ ();
 
 	/* setup LCMS */
 	cmsSetLogErrorHandler (gcm_profile_error_cb);
@@ -1436,13 +1951,12 @@ gcm_profile_finalize (GObject *object)
 	g_free (priv->model);
 	g_free (priv->datetime);
 	g_free (priv->checksum);
-	g_free (priv->vcgt_data);
-	g_free (priv->mlut_data);
-	g_object_unref (priv->white);
-	g_object_unref (priv->black);
-	g_object_unref (priv->red);
-	g_object_unref (priv->green);
-	g_object_unref (priv->blue);
+	gcm_color_free_XYZ (priv->white);
+	gcm_color_free_XYZ (priv->black);
+	gcm_color_free_XYZ (priv->red);
+	gcm_color_free_XYZ (priv->green);
+	gcm_color_free_XYZ (priv->blue);
+	g_hash_table_destroy (profile->priv->dict);
 	if (priv->file != NULL)
 		g_object_unref (priv->file);
 	if (priv->monitor != NULL)
@@ -1459,7 +1973,7 @@ gcm_profile_finalize (GObject *object)
  *
  * Return value: a new #GcmProfile object.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 GcmProfile *
 gcm_profile_new (void)
