@@ -36,8 +36,6 @@
 #include "gcm-calibrate-dialog.h"
 #include "gcm-utils.h"
 
-#include "egg-debug.h"
-
 static void     gcm_calibrate_dialog_finalize	(GObject     *object);
 
 #define GCM_CALIBRATE_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_CALIBRATE_DIALOG, GcmCalibrateDialogPrivate))
@@ -88,10 +86,10 @@ static guint signals[SIGNAL_LAST] = { 0 };
 G_DEFINE_TYPE (GcmCalibrateDialog, gcm_calibrate_dialog, G_TYPE_OBJECT)
 
 /**
- * gcm_calibrate_dialog_emit_response:
+ * gcm_calibrate_dialog_response:
  **/
-static void
-gcm_calibrate_dialog_emit_response (GcmCalibrateDialog *calibrate_dialog, GtkResponseType response)
+void
+gcm_calibrate_dialog_response (GcmCalibrateDialog *calibrate_dialog, GtkResponseType response)
 {
 	calibrate_dialog->priv->response = response;
 	g_signal_emit (calibrate_dialog, signals[SIGNAL_RESPONSE], 0, response);
@@ -108,7 +106,7 @@ static void
 gcm_calibrate_dialog_button_clicked_lcd_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->device_kind = GCM_CALIBRATE_DEVICE_KIND_LCD;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -118,7 +116,7 @@ static void
 gcm_calibrate_dialog_button_clicked_crt_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->device_kind = GCM_CALIBRATE_DEVICE_KIND_CRT;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -128,7 +126,7 @@ static void
 gcm_calibrate_dialog_button_clicked_projector_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->device_kind = GCM_CALIBRATE_DEVICE_KIND_PROJECTOR;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -138,7 +136,7 @@ static void
 gcm_calibrate_dialog_button_clicked_print_local_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_LOCAL;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -148,7 +146,7 @@ static void
 gcm_calibrate_dialog_button_clicked_print_generate_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_GENERATE;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -158,7 +156,7 @@ static void
 gcm_calibrate_dialog_button_clicked_print_analyze_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_ANALYZE;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -168,7 +166,7 @@ static void
 gcm_calibrate_dialog_button_clicked_precision_short_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->precision = GCM_CALIBRATE_PRECISION_SHORT;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -178,7 +176,7 @@ static void
 gcm_calibrate_dialog_button_clicked_precision_normal_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->precision = GCM_CALIBRATE_PRECISION_NORMAL;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -188,7 +186,7 @@ static void
 gcm_calibrate_dialog_button_clicked_precision_long_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
 	calibrate_dialog->priv->precision = GCM_CALIBRATE_PRECISION_LONG;
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -197,7 +195,7 @@ gcm_calibrate_dialog_button_clicked_precision_long_cb (GtkWidget *widget, GcmCal
 static void
 gcm_calibrate_dialog_button_clicked_ok_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_OK);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_OK);
 }
 
 /**
@@ -206,7 +204,7 @@ gcm_calibrate_dialog_button_clicked_ok_cb (GtkWidget *widget, GcmCalibrateDialog
 static void
 gcm_calibrate_dialog_button_clicked_cancel_cb (GtkWidget *widget, GcmCalibrateDialog *calibrate_dialog)
 {
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
 }
 
 /**
@@ -227,7 +225,7 @@ gcm_calibrate_dialog_set_image_filename_private (GcmCalibrateDialog *calibrate_d
 		filename = g_build_filename (GCM_DATA, "icons", image_filename, NULL);
 		pixbuf = gdk_pixbuf_new_from_file_at_size (filename, 200, 400, &error);
 		if (pixbuf == NULL) {
-			egg_warning ("failed to load image: %s", error->message);
+			g_warning ("failed to load image: %s", error->message);
 			g_error_free (error);
 			gtk_widget_hide (widget);
 		} else {
@@ -286,7 +284,7 @@ gcm_calibrate_dialog_set_window	(GcmCalibrateDialog *calibrate_dialog, GtkWindow
 	/* ensure it's not the same thing */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "dialog_calibrate"));
 	if (GTK_WINDOW (widget) == window) {
-		egg_warning ("trying to set parent to self!");
+		g_warning ("trying to set parent to self!");
 		return;
 	}
 
@@ -311,8 +309,10 @@ gcm_calibrate_dialog_get_window (GcmCalibrateDialog *calibrate_dialog)
 GtkResponseType
 gcm_calibrate_dialog_run (GcmCalibrateDialog *calibrate_dialog)
 {
-	if (g_main_loop_is_running (calibrate_dialog->priv->loop))
-		egg_error ("you can't call this recursively");
+	if (g_main_loop_is_running (calibrate_dialog->priv->loop)) {
+		g_warning ("you can't call this recursively");
+		return GTK_RESPONSE_NONE;
+	}
 
 	g_main_loop_run (calibrate_dialog->priv->loop);
 	return calibrate_dialog->priv->response;
@@ -386,7 +386,7 @@ gcm_calibrate_dialog_show (GcmCalibrateDialog		*calibrate_dialog,
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "dialog_calibrate"));
 	if (calibrate_dialog->priv->move_window) {
 		gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
-		egg_debug ("currently at %i,%i, moving left", x, y);
+		g_debug ("currently at %i,%i, moving left", x, y);
 		gtk_window_move (GTK_WINDOW (widget), 10, y);
 	}
 
@@ -419,7 +419,7 @@ gcm_calibrate_dialog_pop (GcmCalibrateDialog *calibrate_dialog)
 	/* save in case we need to reuse */
 	len = priv->cached_dialogs->len;
 	if (len < 2) {
-		egg_warning ("cannot pop dialog as nothing to recover");
+		g_warning ("cannot pop dialog as nothing to recover");
 		return;
 	}
 	dialog = g_ptr_array_index (priv->cached_dialogs, len-2);
@@ -523,7 +523,7 @@ gcm_calibrate_dialog_set_move_window (GcmCalibrateDialog *calibrate_dialog, gboo
 static gboolean
 gcm_calibrate_dialog_delete_event_cb (GtkWidget *widget, GdkEvent *event, GcmCalibrateDialog *calibrate_dialog)
 {
-	gcm_calibrate_dialog_emit_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
+	gcm_calibrate_dialog_response (calibrate_dialog, GTK_RESPONSE_CANCEL);
 	return FALSE;
 }
 
@@ -773,7 +773,7 @@ gcm_calibrate_dialog_init (GcmCalibrateDialog *calibrate_dialog)
 	calibrate_dialog->priv->builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (calibrate_dialog->priv->builder, GCM_DATA "/gcm-calibrate.ui", &error);
 	if (retval == 0) {
-		egg_error ("failed to load ui: %s", error->message);
+		g_error ("failed to load ui: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -823,8 +823,8 @@ gcm_calibrate_dialog_init (GcmCalibrateDialog *calibrate_dialog)
 
 	/* add the list of charts */
 	for (i = 0; i < GCM_CALIBRATE_REFERENCE_KIND_UNKNOWN; i++) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget),
-					   gcm_calibrate_dialog_reference_kind_to_localised_string (i));
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget),
+						gcm_calibrate_dialog_reference_kind_to_localised_string (i));
 	}
 
 	/* use IT8 by default */
@@ -867,30 +867,3 @@ gcm_calibrate_dialog_new (void)
 	return GCM_CALIBRATE_DIALOG (gcm_calibrate_dialog_object);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gcm_calibrate_dialog_test (EggTest *test)
-{
-	GcmCalibrateDialog *calibrate_dialog;
-//	gboolean ret;
-//	GError *error = NULL;
-
-	if (!egg_test_start (test, "GcmCalibrateDialog"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get a calibrate_dialog object");
-	calibrate_dialog = gcm_calibrate_dialog_new ();
-	egg_test_assert (test, calibrate_dialog != NULL);
-
-	g_object_unref (calibrate_dialog);
-
-	egg_test_end (test);
-}
-#endif
-
