@@ -32,7 +32,7 @@
 #include <gtk/gtk.h>
 
 #include "gcm-calibrate.h"
-#include "gcm-xyz.h"
+#include "gcm-color.h"
 #include "gcm-dmi.h"
 #include "gcm-device-xrandr.h"
 #include "gcm-utils.h"
@@ -41,8 +41,6 @@
 #include "gcm-calibrate-dialog.h"
 #include "gcm-exif.h"
 
-#include "egg-debug.h"
-
 static void     gcm_calibrate_finalize	(GObject     *object);
 
 #define GCM_CALIBRATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_CALIBRATE, GcmCalibratePrivate))
@@ -60,10 +58,10 @@ struct _GcmCalibratePrivate
 	GcmCalibrateDeviceKind		 calibrate_device_kind;
 	GcmCalibratePrintKind		 print_kind;
 	GcmCalibratePrecision		 precision;
-	GcmSensorKind		 sensor_kind;
+	GcmSensorKind			 sensor_kind;
 	GcmCalibrateDialog		*calibrate_dialog;
 	GcmDeviceKind			 device_kind;
-	GcmXyz				*xyz;
+	GcmColorXYZ			*xyz;
 	gchar				*output_name;
 	gchar				*filename_source;
 	gchar				*filename_reference;
@@ -127,59 +125,85 @@ out:
 }
 
 /**
- * gcm_calibrate_get_model_fallback:
+ * gcm_calibrate_get_device_fallback:
  **/
-const gchar *
-gcm_calibrate_get_model_fallback (GcmCalibrate *calibrate)
+gchar *
+gcm_calibrate_get_profile_copyright (GcmCalibrate *calibrate)
 {
-	GcmCalibratePrivate *priv = calibrate->priv;
-	if (priv->model != NULL)
-		return priv->model;
+	gchar *text;
+	GDate *date = NULL;
 
-	/* TRANSLATORS: this is saved in the profile */
-	return _("Unknown model");
-}
+	/* create date and set it to now */
+	date = g_date_new ();
+	g_date_set_time_t (date, time (NULL));
 
-/**
- * gcm_calibrate_get_description_fallback:
- **/
-const gchar *
-gcm_calibrate_get_description_fallback (GcmCalibrate *calibrate)
-{
-	GcmCalibratePrivate *priv = calibrate->priv;
-	if (priv->description != NULL)
-		return priv->description;
+	/* TRANSLATORS: this is the copyright string, where it might be "Copyright (c) 2009 Edward Scissorhands" - YOU NEED TO USE ASCII ONLY */
+	text = g_strdup_printf ("%s %04i %s", _("Copyright (c)"), date->year, g_get_real_name ());
 
-	/* TRANSLATORS: this is saved in the profile */
-	return _("Unknown description");
-}
-
-/**
- * gcm_calibrate_get_manufacturer_fallback:
- **/
-const gchar *
-gcm_calibrate_get_manufacturer_fallback (GcmCalibrate *calibrate)
-{
-	GcmCalibratePrivate *priv = calibrate->priv;
-	if (priv->manufacturer != NULL)
-		return priv->manufacturer;
-
-	/* TRANSLATORS: this is saved in the profile */
-	return _("Unknown manufacturer");
+	g_date_free (date);
+	return text;
 }
 
 /**
  * gcm_calibrate_get_device_fallback:
  **/
-const gchar *
-gcm_calibrate_get_device_fallback (GcmCalibrate *calibrate)
+gchar *
+gcm_calibrate_get_profile_description (GcmCalibrate *calibrate)
+{
+	gchar *text;
+	GDate *date = NULL;
+	const gchar *description;
+	GcmCalibratePrivate *priv = calibrate->priv;
+
+	/* create date and set it to now */
+	date = g_date_new ();
+	g_date_set_time_t (date, time (NULL));
+
+	/* we've got something set */
+	if (priv->description != NULL) {
+		description = priv->description;
+	} else {
+		/* TRANSLATORS: this is saved in the profile */
+		description = _("Unknown description");
+	}
+
+	/* get description */
+	text = g_strdup_printf ("%s, %s (%04i-%02i-%02i)", priv->device, description, date->year, date->month, date->day);
+
+	g_date_free (date);
+	return text;
+}
+
+/**
+ * gcm_calibrate_get_device_fallback:
+ **/
+gchar *
+gcm_calibrate_get_profile_model (GcmCalibrate *calibrate)
 {
 	GcmCalibratePrivate *priv = calibrate->priv;
-	if (priv->device != NULL)
-		return priv->device;
+
+	/* we've got something set */
+	if (priv->model != NULL)
+		return g_strdup (priv->model);
 
 	/* TRANSLATORS: this is saved in the profile */
-	return _("Unknown device");
+	return g_strdup (_("Unknown model"));
+}
+
+/**
+ * gcm_calibrate_get_device_fallback:
+ **/
+gchar *
+gcm_calibrate_get_profile_manufacturer (GcmCalibrate *calibrate)
+{
+	GcmCalibratePrivate *priv = calibrate->priv;
+
+	/* we've got something set */
+	if (priv->manufacturer != NULL)
+		return g_strdup (priv->manufacturer);
+
+	/* TRANSLATORS: this is saved in the profile */
+	return g_strdup (_("Unknown manufacturer"));
 }
 
 /**
@@ -218,6 +242,15 @@ gcm_calibrate_get_working_path (GcmCalibrate *calibrate)
 	return calibrate->priv->working_path;
 }
 
+/**
+ * gcm_calibrate_get_basename:
+ **/
+const gchar *
+gcm_calibrate_get_basename (GcmCalibrate *calibrate)
+{
+	return calibrate->priv->basename;
+}
+
 /**
  * gcm_calibrate_set_basename:
  **/
@@ -467,7 +500,6 @@ gcm_calibrate_set_working_path (GcmCalibrate *calibrate, GError **error)
 	return ret;
 }
 
-
 /**
  * gcm_calibrate_get_precision:
  **/
@@ -566,6 +598,7 @@ gcm_calibrate_display (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 	GError *error_tmp = NULL;
 	gchar *precision = NULL;
 	GcmCalibratePrivate *priv = calibrate->priv;
+	GcmSensor *sensor;
 
 	/* coldplug source */
 	if (priv->output_name == NULL) {
@@ -593,7 +626,16 @@ gcm_calibrate_display (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 	}
 
 	/* get calibration device model */
-	hardware_device = gcm_sensor_get_model (gcm_sensor_client_get_sensor (priv->sensor_client));
+	sensor = gcm_sensor_client_get_sensor (priv->sensor_client);
+	if (sensor == NULL) {
+		ret = FALSE;
+		g_set_error_literal (error,
+				     GCM_CALIBRATE_ERROR,
+				     GCM_CALIBRATE_ERROR_INTERNAL,
+				     "no sensor found");
+		goto out;
+	}
+	hardware_device = gcm_sensor_get_model (sensor);
 
 	/* get device, harder */
 	if (hardware_device == NULL) {
@@ -678,7 +720,7 @@ gcm_calibrate_display (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 		/* get the old brightness so we can restore state */
 		ret = gcm_brightness_get_percentage (brightness, &percentage, &error_tmp);
 		if (!ret) {
-			egg_warning ("failed to get brightness: %s", error_tmp->message);
+			g_warning ("failed to get brightness: %s", error_tmp->message);
 			g_error_free (error_tmp);
 			/* not fatal */
 			error_tmp = NULL;
@@ -687,7 +729,7 @@ gcm_calibrate_display (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 		/* set the new brightness */
 		ret = gcm_brightness_set_percentage (brightness, 100, &error_tmp);
 		if (!ret) {
-			egg_warning ("failed to set brightness: %s", error_tmp->message);
+			g_warning ("failed to set brightness: %s", error_tmp->message);
 			g_error_free (error_tmp);
 			/* not fatal */
 			error_tmp = NULL;
@@ -702,7 +744,7 @@ out:
 		/* set the new brightness */
 		ret_tmp = gcm_brightness_set_percentage (brightness, percentage, &error_tmp);
 		if (!ret_tmp) {
-			egg_warning ("failed to restore brightness: %s", error_tmp->message);
+			g_warning ("failed to restore brightness: %s", error_tmp->message);
 			g_error_free (error_tmp);
 			/* not fatal */
 			error = NULL;
@@ -717,7 +759,6 @@ out:
 	return ret;
 }
 
-
 /**
  * gcm_calibrate_device_get_reference_image:
  **/
@@ -833,7 +874,7 @@ gcm_calibrate_get_device_for_it8_file (const gchar *filename)
 	/* get contents */
 	ret = g_file_get_contents (filename, &contents, NULL, &error);
 	if (!ret) {
-		egg_warning ("failed to get contents: %s", error->message);
+		g_warning ("failed to get contents: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -1048,7 +1089,7 @@ gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error
 		if (response == GTK_RESPONSE_YES)
 			has_shared_targets = gcm_utils_install_package (GCM_PREFS_PACKAGE_NAME_SHARED_COLOR_TARGETS, window);
 #else
-		egg_warning ("cannot install: this package was not compiled with --enable-packagekit");
+		g_warning ("cannot install: this package was not compiled with --enable-packagekit");
 #endif
 	}
 
@@ -1128,7 +1169,7 @@ gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error
 	/* use the exif data if there is any present */
 	ret = gcm_calibrate_set_from_exif (calibrate, reference_image, NULL);
 	if (!ret)
-		egg_debug ("no EXIF data, so using device attributes");
+		g_debug ("no EXIF data, so using device attributes");
 
 	/* get reference data */
 	directory = has_shared_targets ? "/usr/share/color/targets" : "/media";
@@ -1242,7 +1283,7 @@ gcm_calibrate_get_property (GObject *object, guint prop_id, GValue *value, GPara
 		g_value_set_uint (value, priv->precision);
 		break;
 	case PROP_XYZ:
-		g_value_set_object (value, priv->xyz);
+		g_value_set_boxed (value, g_boxed_copy (GCM_TYPE_COLOR_XYZ, priv->xyz));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1340,8 +1381,8 @@ gcm_calibrate_set_property (GObject *object, guint prop_id, const GValue *value,
 		break;
 	case PROP_XYZ:
 		if (priv->xyz != NULL)
-			g_object_unref (priv->xyz);
-		priv->xyz = g_value_dup_object (value);
+			gcm_color_free_XYZ (priv->xyz);
+		priv->xyz = g_boxed_copy (GCM_TYPE_COLOR_XYZ, value);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1500,9 +1541,9 @@ gcm_calibrate_class_init (GcmCalibrateClass *klass)
 	/**
 	 * GcmCalibrate:xyz:
 	 */
-	pspec = g_param_spec_object ("xyz", NULL, NULL,
-				     GCM_TYPE_XYZ,
-				     G_PARAM_READWRITE);
+	pspec = g_param_spec_boxed ("xyz", NULL, NULL,
+				    GCM_TYPE_COLOR_XYZ,
+				    G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_XYZ, pspec);
 
 	g_type_class_add_private (klass, sizeof (GcmCalibratePrivate));
@@ -1527,7 +1568,7 @@ gcm_calibrate_init (GcmCalibrate *calibrate)
 	calibrate->priv->description = NULL;
 	calibrate->priv->device = NULL;
 	calibrate->priv->serial = NULL;
-	calibrate->priv->xyz = gcm_xyz_new ();
+	calibrate->priv->xyz = gcm_color_new_XYZ ();
 	calibrate->priv->working_path = NULL;
 	calibrate->priv->calibrate_device_kind = GCM_CALIBRATE_DEVICE_KIND_UNKNOWN;
 	calibrate->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_UNKNOWN;
@@ -1573,8 +1614,7 @@ gcm_calibrate_finalize (GObject *object)
 	g_free (priv->serial);
 	g_free (priv->working_path);
 	g_signal_handlers_disconnect_by_func (calibrate->priv->sensor_client, G_CALLBACK (gcm_prefs_sensor_client_changed_cb), calibrate);
-	if (priv->xyz != NULL)
-		g_object_unref (priv->xyz);
+	gcm_color_free_XYZ (priv->xyz);
 	g_object_unref (priv->sensor_client);
 	g_object_unref (priv->dmi);
 	g_object_unref (priv->calibrate_dialog);
