@@ -30,13 +30,12 @@
 #include <gtk/gtk.h>
 #include <lcms2.h>
 
-#include "egg-debug.h"
-
 #include "gcm-calibrate-argyll.h"
 #include "gcm-sensor-client.h"
 #include "gcm-profile-store.h"
 #include "gcm-utils.h"
-#include "gcm-xyz.h"
+#include "gcm-color.h"
+#include "gcm-debug.h"
 
 static GtkBuilder *builder = NULL;
 static GtkWidget *info_bar_hardware = NULL;
@@ -48,6 +47,8 @@ static gboolean done_measure = FALSE;
 static GcmSensor *sensor = NULL;
 static GcmColorXYZ last_sample;
 static gdouble last_ambient = -1.0f;
+static guint xid = 0;
+static GcmSensorClient *sensor_client = NULL;
 
 enum {
 	GCM_PREFS_COMBO_COLUMN_TEXT,
@@ -236,7 +237,7 @@ gcm_picker_measure_cb (GtkWidget *widget, gpointer data)
 		/* sample color */
 		ret = gcm_sensor_sample (sensor, NULL, &last_sample, &error);
 		if (!ret) {
-			egg_warning ("failed to measure: %s", error->message);
+			g_warning ("failed to measure: %s", error->message);
 			g_error_free (error);
 			goto out;
 		}
@@ -247,7 +248,7 @@ gcm_picker_measure_cb (GtkWidget *widget, gpointer data)
 		window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_picker"));
 		ret = gcm_calibrate_spotread (calibrate, window, &error);
 		if (!ret) {
-			egg_warning ("failed to get spot color: %s", error->message);
+			g_warning ("failed to get spot color: %s", error->message);
 			g_error_free (error);
 			goto out;
 		}
@@ -262,7 +263,7 @@ out:
 static void
 gcm_picker_xyz_notify_cb (GcmCalibrate *calibrate_, GParamSpec *pspec, gpointer user_data)
 {
-	GcmXyz *xyz;
+	GcmColorXYZ *xyz;
 
 	/* get new value */
 	g_object_get (calibrate, "xyz", &xyz, NULL);
@@ -275,7 +276,7 @@ gcm_picker_xyz_notify_cb (GcmCalibrate *calibrate_, GParamSpec *pspec, gpointer
 
 	gcm_picker_refresh_results ();
 	gcm_picker_got_results ();
-	g_object_unref (xyz);
+	gcm_color_free_XYZ (xyz);
 }
 
 /**
@@ -285,7 +286,7 @@ static void
 gcm_picker_close_cb (GtkWidget *widget, gpointer data)
 {
 	GtkApplication *application = (GtkApplication *) data;
-	gtk_application_quit (application);
+	g_application_release (G_APPLICATION (application));
 }
 
 /**
@@ -311,7 +312,7 @@ gcm_picker_delete_event_cb (GtkWidget *widget, GdkEvent *event, gpointer data)
  * gcm_picker_sensor_client_setup_ui:
  **/
 static void
-gcm_picker_sensor_client_setup_ui (GcmSensorClient *sensor_client)
+gcm_picker_sensor_client_setup_ui (GcmSensorClient *_sensor_client)
 {
 	gboolean ret = FALSE;
 	GtkWidget *widget;
@@ -356,7 +357,7 @@ out:
  * gcm_picker_sensor_client_changed_cb:
  **/
 static void
-gcm_picker_sensor_client_changed_cb (GcmSensorClient *sensor_client, gpointer user_data)
+gcm_picker_sensor_client_changed_cb (GcmSensorClient *_sensor_client, gpointer user_data)
 {
 	gcm_picker_sensor_client_setup_ui (sensor_client);
 }
@@ -365,14 +366,14 @@ gcm_picker_sensor_client_changed_cb (GcmSensorClient *sensor_client, gpointer us
  * gcm_window_set_parent_xid:
  **/
 static void
-gcm_window_set_parent_xid (GtkWindow *window, guint32 xid)
+gcm_window_set_parent_xid (GtkWindow *window, guint32 _xid)
 {
 	GdkDisplay *display;
 	GdkWindow *parent_window;
 	GdkWindow *our_window;
 
 	display = gdk_display_get_default ();
-	parent_window = gdk_window_foreign_new_for_display (display, xid);
+	parent_window = gdk_window_foreign_new_for_display (display, _xid);
 	our_window = gtk_widget_get_window (GTK_WIDGET (window));
 
 	/* set this above our parent */
@@ -386,7 +387,7 @@ gcm_window_set_parent_xid (GtkWindow *window, guint32 xid)
 static void
 gcm_picker_error_cb (cmsContext ContextID, cmsUInt32Number errorcode, const char *text)
 {
-	egg_warning ("LCMS error %i: %s", errorcode, text);
+	g_warning ("LCMS error %i: %s", errorcode, text);
 }
 
 /**
@@ -414,7 +415,7 @@ gcm_prefs_space_combo_changed_cb (GtkWidget *widget, gpointer data)
 		goto out;
 
 	profile_filename = gcm_profile_get_filename (profile);
-	egg_debug ("changed picker space %s", profile_filename);
+	g_debug ("changed picker space %s", profile_filename);
 
 	gcm_picker_refresh_results ();
 out:
@@ -462,7 +463,6 @@ gcm_prefs_combobox_add_profile (GtkWidget *widget, GcmProfile *profile, GtkTreeI
 	if (iter == NULL)
 		iter = &iter_tmp;
 
-
 	/* also add profile */
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX(widget));
 	description = gcm_profile_get_description (profile);
@@ -489,6 +489,7 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 	gchar *text = NULL;
 	GPtrArray *profile_array = NULL;
 	GtkTreeIter iter;
+	GtkTreeModel *model;
 
 	/* get new list */
 	profile_array = gcm_profile_store_get_array (profile_store);
@@ -516,7 +517,11 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 		/* TRANSLATORS: this is when there are no profiles that can be used; the search term is either "RGB" or "CMYK" */
 		text = g_strdup_printf (_("No %s color spaces available"),
 					gcm_colorspace_to_localised_string (GCM_COLORSPACE_RGB));
-		gtk_combo_box_append_text (GTK_COMBO_BOX(widget), text);
+		model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
+		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+				    GCM_PREFS_COMBO_COLUMN_TEXT, text,
+				    -1);
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 		gtk_widget_set_sensitive (widget, FALSE);
 	}
@@ -526,62 +531,38 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 }
 
 /**
- * main:
+ * gcm_picker_activate_cb:
  **/
-int
-main (int argc, char *argv[])
+static void
+gcm_picker_activate_cb (GApplication *application, gpointer user_data)
+{
+	GtkWindow *window;
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_picker"));
+	gtk_window_present (window);
+}
+
+/**
+ * gcm_picker_startup_cb:
+ **/
+static void
+gcm_picker_startup_cb (GApplication *application, gpointer user_data)
 {
-	GOptionContext *context;
 	guint retval = 0;
 	GError *error = NULL;
-	GtkApplication *application;
 	GtkWidget *main_window;
 	GtkWidget *widget;
-	guint xid = 0;
-	GcmSensorClient *sensor_client = NULL;
-
-	const GOptionEntry options[] = {
-		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
-		  /* TRANSLATORS: we can make this modal (stay on top of) another window */
-		  _("Set the parent window to make this modal"), NULL },
-		{ NULL}
-	};
-
-	/* setup translations */
-	setlocale (LC_ALL, "");
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
-	/* setup type system */
-	g_type_init ();
-
-	/* setup LCMS */
-	cmsSetLogErrorHandler (gcm_picker_error_cb);
-
-	context = g_option_context_new (NULL);
-	/* TRANSLATORS: tool that is used to pick colors */
-	g_option_context_set_summary (context, _("GNOME Color Manager Color Picker"));
-	g_option_context_add_group (context, egg_debug_get_option_group ());
-	g_option_context_add_group (context, gtk_get_option_group (TRUE));
-	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_parse (context, &argc, &argv, NULL);
-	g_option_context_free (context);
-
-	/* ensure single instance */
-	application = gtk_application_new ("org.gnome.ColorManager.Picker", &argc, &argv);
 
 	/* get UI */
 	builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (builder, GCM_DATA "/gcm-picker.ui", &error);
 	if (retval == 0) {
-		egg_warning ("failed to load ui: %s", error->message);
+		g_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
 
 	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_picker"));
-	gtk_application_add_window (application, GTK_WINDOW (main_window));
+	gtk_application_add_window (GTK_APPLICATION (application), GTK_WINDOW (main_window));
 	gtk_window_set_icon_name (GTK_WINDOW (main_window), GCM_STOCK_ICON);
 	g_signal_connect (main_window, "delete_event",
 			  G_CALLBACK (gcm_picker_delete_event_cb), application);
@@ -614,7 +595,7 @@ main (int argc, char *argv[])
 
 	/* set the parent window if it is specified */
 	if (xid != 0) {
-		egg_debug ("Setting xid %i", xid);
+		g_debug ("Setting xid %i", xid);
 		gcm_window_set_parent_xid (GTK_WINDOW (main_window), xid);
 	}
 
@@ -661,9 +642,57 @@ main (int argc, char *argv[])
 
 	/* wait */
 	gtk_widget_show (main_window);
-	gtk_application_run (application);
-
 out:
+	return;
+}
+
+/**
+ * main:
+ **/
+int
+main (int argc, char *argv[])
+{
+	GOptionContext *context;
+	GtkApplication *application;
+	int status = 0;
+
+	const GOptionEntry options[] = {
+		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
+		  /* TRANSLATORS: we can make this modal (stay on top of) another window */
+		  _("Set the parent window to make this modal"), NULL },
+		{ NULL}
+	};
+
+	/* setup translations */
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
+	/* setup type system */
+	g_type_init ();
+
+	/* setup LCMS */
+	cmsSetLogErrorHandler (gcm_picker_error_cb);
+
+	context = g_option_context_new (NULL);
+	/* TRANSLATORS: tool that is used to pick colors */
+	g_option_context_set_summary (context, _("GNOME Color Manager Color Picker"));
+	g_option_context_add_group (context, gcm_debug_get_option_group ());
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
+	g_option_context_add_main_entries (context, options, NULL);
+	g_option_context_parse (context, &argc, &argv, NULL);
+	g_option_context_free (context);
+
+	/* ensure single instance */
+	application = gtk_application_new ("org.gnome.ColorManager.Picker", 0);
+	g_signal_connect (application, "startup",
+			  G_CALLBACK (gcm_picker_startup_cb), NULL);
+	g_signal_connect (application, "activate",
+			  G_CALLBACK (gcm_picker_activate_cb), NULL);
+
+	status = g_application_run (G_APPLICATION (application), argc, argv);
+
 	g_object_unref (application);
 	if (profile_store != NULL)
 		g_object_unref (profile_store);
@@ -673,6 +702,6 @@ out:
 		g_object_unref (calibrate);
 	if (builder != NULL)
 		g_object_unref (builder);
-	return retval;
+	return status;
 }
 
