@@ -24,10 +24,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <locale.h>
-#ifdef HAVE_NOTIFY
 #include <libnotify/notify.h>
-#endif
-#include "egg-debug.h"
 
 #include "gcm-client.h"
 #include "gcm-device-xrandr.h"
@@ -36,6 +33,7 @@
 #include "gcm-utils.h"
 #include "gcm-client.h"
 #include "gcm-profile-store.h"
+#include "gcm-debug.h"
 
 static GMainLoop *loop = NULL;
 static GSettings *settings = NULL;
@@ -58,9 +56,9 @@ gcm_session_check_idle_cb (gpointer user_data)
 
 	/* get the idle time */
 	idle = (guint) g_timer_elapsed (timer, NULL);
-	egg_debug ("we've been idle for %is", idle);
+	g_debug ("we've been idle for %is", idle);
 	if (idle > GCM_SESSION_IDLE_EXIT) {
-		egg_debug ("exiting loop as idle");
+		g_debug ("exiting loop as idle");
 		g_main_loop_quit (loop);
 		return FALSE;
 	}
@@ -68,7 +66,6 @@ gcm_session_check_idle_cb (gpointer user_data)
 	return TRUE;
 }
 
-#ifdef HAVE_NOTIFY
 /**
  * gcm_session_notify_cb:
  **/
@@ -85,12 +82,11 @@ gcm_session_notify_cb (NotifyNotification *notification, gchar *action, gpointer
 	} else if (g_strcmp0 (action, "recalibrate") == 0) {
 		ret = g_spawn_command_line_async ("gcm-prefs", &error);
 		if (!ret) {
-			egg_warning ("failed to spawn: %s", error->message);
+			g_warning ("failed to spawn: %s", error->message);
 			g_error_free (error);
 		}
 	}
 }
-#endif
 
 /**
  * gcm_session_notify_recalibrate:
@@ -103,7 +99,7 @@ gcm_session_notify_recalibrate (const gchar *title, const gchar *message, GcmDev
 	NotifyNotification *notification;
 
 	/* show a bubble */
-	notification = notify_notification_new (title, message, GCM_STOCK_ICON, NULL);
+	notification = notify_notification_new (title, message, GCM_STOCK_ICON);
 	notify_notification_set_timeout (notification, GCM_SESSION_NOTIFY_TIMEOUT);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 
@@ -115,7 +111,7 @@ gcm_session_notify_recalibrate (const gchar *title, const gchar *message, GcmDev
 
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
-		egg_warning ("failed to show notification: %s", error->message);
+		g_warning ("failed to show notification: %s", error->message);
 		g_error_free (error);
 	}
 	return ret;
@@ -185,14 +181,14 @@ gcm_session_added_cb (GcmClient *client_, GcmDevice *device, gpointer user_data)
 	/* ensure we have a profile */
 	profile = gcm_device_get_default_profile_filename (device);
 	if (profile == NULL) {
-		egg_debug ("no profile set for %s", gcm_device_get_id (device));
+		g_debug ("no profile set for %s", gcm_device_get_id (device));
 		goto out;
 	}
 
 	/* ensure it's a profile generated by us */
 	basename = g_path_get_basename (profile);
 	if (!g_str_has_prefix (basename, "GCM")) {
-		egg_debug ("not a GCM profile for %s: %s", gcm_device_get_id (device), profile);
+		g_debug ("not a GCM profile for %s: %s", gcm_device_get_id (device), profile);
 		goto out;
 	}
 
@@ -217,7 +213,7 @@ gcm_session_get_profile_for_window (guint xid, GError **error)
 	GdkWindow *window;
 	const gchar *filename = NULL;
 
-	egg_debug ("getting profile for %i", xid);
+	g_debug ("getting profile for %i", xid);
 
 	/* get window for xid */
 	window = gdk_window_foreign_new (xid);
@@ -323,7 +319,7 @@ gcm_session_get_profiles_for_file (const gchar *filename, GError **error)
 		goto out;
 
 	/* get list */
-	egg_debug ("query=%s", filename);
+	g_debug ("query=%s", filename);
 	array_devices = gcm_client_get_devices (client);
 	for (i=0; i<array_devices->len; i++) {
 		device = g_ptr_array_index (array_devices, i);
@@ -377,7 +373,7 @@ gcm_session_get_profiles_for_device (const gchar *device_id_with_prefix, GError
 		use_native_device = TRUE;
 
 	/* get list */
-	egg_debug ("query=%s [%s] %i", device_id_with_prefix, device_id, use_native_device);
+	g_debug ("query=%s [%s] %i", device_id_with_prefix, device_id, use_native_device);
 	array_devices = gcm_client_get_devices (client);
 	for (i=0; i<array_devices->len; i++) {
 		device = g_ptr_array_index (array_devices, i);
@@ -394,7 +390,7 @@ gcm_session_get_profiles_for_device (const gchar *device_id_with_prefix, GError
 			continue;
 
 		/* compare what we have against what we were given */
-		egg_debug ("comparing %s with %s", device_id_tmp, device_id);
+		g_debug ("comparing %s with %s", device_id_tmp, device_id);
 		if (g_strcmp0 (device_id_tmp, device_id) == 0) {
 			array = gcm_device_get_profiles (device);
 			break;
@@ -589,6 +585,8 @@ gcm_session_handle_get_property (GDBusConnection *connection_, const gchar *send
 		retval = g_settings_get_value (settings, GCM_SETTINGS_COLORSPACE_RGB);
 	} else if (g_strcmp0 (property_name, "ColorspaceCmyk") == 0) {
 		retval = g_settings_get_value (settings, GCM_SETTINGS_COLORSPACE_CMYK);
+	} else if (g_strcmp0 (property_name, "ColorspaceGray") == 0) {
+		retval = g_settings_get_value (settings, GCM_SETTINGS_COLORSPACE_GRAY);
 	}
 
 	/* reset time */
@@ -626,7 +624,7 @@ gcm_session_on_bus_acquired (GDBusConnection *connection_, const gchar *name, gp
 static void
 gcm_session_on_name_acquired (GDBusConnection *connection_, const gchar *name, gpointer user_data)
 {
-	egg_debug ("acquired name: %s", name);
+	g_debug ("acquired name: %s", name);
 	connection = g_object_ref (connection_);
 }
 
@@ -636,7 +634,7 @@ gcm_session_on_name_acquired (GDBusConnection *connection_, const gchar *name, g
 static void
 gcm_session_on_name_lost (GDBusConnection *connection_, const gchar *name, gpointer user_data)
 {
-	egg_debug ("lost name: %s", name);
+	g_debug ("lost name: %s", name);
 	g_main_loop_quit (loop);
 }
 
@@ -662,7 +660,7 @@ gcm_session_emit_changed (void)
 					     NULL,
 					     &error);
 	if (!ret) {
-		egg_warning ("failed to emit signal: %s", error->message);
+		g_warning ("failed to emit signal: %s", error->message);
 		g_error_free (error);
 	}
 }
@@ -700,6 +698,7 @@ main (int argc, char *argv[])
 	guint poll_id = 0;
 	GFile *file = NULL;
 	gchar *introspection_data = NULL;
+	GcmProfileSearchFlags search_flags = GCM_PROFILE_STORE_SEARCH_ALL;
 
 	const GOptionEntry options[] = {
 		{ "no-timed-exit", '\0', 0, G_OPTION_ARG_NONE, &no_timed_exit,
@@ -723,7 +722,7 @@ main (int argc, char *argv[])
 	context = g_option_context_new (NULL);
 	g_option_context_set_summary (context, _("Color Management D-Bus Service"));
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gcm_debug_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
@@ -744,13 +743,19 @@ main (int argc, char *argv[])
 
 	/* have access to all profiles */
 	profile_store = gcm_profile_store_new ();
-	gcm_profile_store_search (profile_store, GCM_PROFILE_STORE_SEARCH_ALL);
+
+	/* volume checking is optional */
+	ret = g_settings_get_boolean (settings, GCM_SETTINGS_USE_PROFILES_FROM_VOLUMES);
+	if (!ret)
+		search_flags &= ~GCM_PROFILE_STORE_SEARCH_VOLUMES;
+
+	gcm_profile_store_search (profile_store, search_flags);
 	timer = g_timer_new ();
 
 	/* get all connected devices */
 	ret = gcm_client_coldplug (client, GCM_CLIENT_COLDPLUG_ALL, &error);
 	if (!ret) {
-		egg_warning ("failed to coldplug: %s", error->message);
+		g_warning ("failed to coldplug: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -761,7 +766,7 @@ main (int argc, char *argv[])
 	file = g_file_new_for_path (DATADIR "/dbus-1/interfaces/org.gnome.ColorManager.xml");
 	ret = g_file_load_contents (file, NULL, &introspection_data, NULL, NULL, &error);
 	if (!ret) {
-		egg_warning ("failed to load introspection: %s", error->message);
+		g_warning ("failed to load introspection: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -769,7 +774,7 @@ main (int argc, char *argv[])
 	/* build introspection from XML */
 	introspection = g_dbus_node_info_new_for_xml (introspection_data, &error);
 	if (introspection == NULL) {
-		egg_warning ("failed to load introspection: %s", error->message);
+		g_warning ("failed to load introspection: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
